# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/app/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\App\\": "packages/litecms/app/src",
            "Litecms\\App\\Seeders\\": "packages/litecms/app/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\App\Providers\AppServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'App'  => Litecms\App\Facades\App::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\App\\Seeders\\AppTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\App\Providers\AppServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\App\Providers\AppServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\App\Providers\AppServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/app/{modulename}

**User**

    http://path-to-route-folder/user/app/{modulename}

**Public**

    http://path-to-route-folder/apps


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/app/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/app/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/app/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/app/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/app/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/app/{modulename}/{slug}
    METHOD: GET