<?php

namespace Litecms\App\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Database\RequestScope;
use Litecms\App\Http\Resources\AppResource;
use Litecms\App\Http\Resources\AppsCollection;
use Litecms\App\Scopes\AppPermissionPublicScope;
use Litecms\App\Models\AppPermission;

class AppPermissionPublicController extends BaseController
{

    /**
     * Show app_permission's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = AppPermission::pushScope(new RequestScope())
            ->pushScope(new AppPermissionPublicScope())
            ->select('app_permissions.*')
            ->paginate($pageLimit)
            ->withQueryString();

        $data = new AppPermissionsCollection($page);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('app::app_permission.names'))
            ->view('app::public.app_permission.index')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show app_permission.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $model = AppPermission::findBySlug($slug);
        $data = new AppPermissionResource($model);

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('app::app_permission.name'))
            ->view('app::public.app_permission.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
