<?php

namespace Litecms\App\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\App\Models\AppPermission;

class AppPermissionPolicy
{

    /**
     * Determine if the given user can view the app_permission.
     *
     * @param UserPolicyInterface $authUser
     * @param AppPermission $app_permission
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, AppPermission $app_permission)
    {
        if ($authUser->canDo('app.app_permission.view') && $authUser->isAdmin()) {
            return true;
        }

        return $app_permission->user_id == user_id() && $app_permission->user_type == user_type();
    }

    /**
     * Determine if the given user can create a app_permission.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('app.app_permission.create');
    }

    /**
     * Determine if the given user can update the given app_permission.
     *
     * @param UserPolicyInterface $authUser
     * @param AppPermission $app_permission
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, AppPermission $app_permission)
    {
        if ($authUser->canDo('app.app_permission.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $app_permission->user_id == user_id() && $app_permission->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given app_permission.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, AppPermission $app_permission)
    {
        return $app_permission->user_id == user_id() && $app_permission->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given app_permission.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, AppPermission $app_permission)
    {
        if ($authUser->canDo('app.app_permission.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given app_permission.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, AppPermission $app_permission)
    {
        if ($authUser->canDo('app.app_permission.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
