<?php

namespace Litecms\App\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\App\Models\Apps;

class AppsPolicy
{

    /**
     * Determine if the given user can view the apps.
     *
     * @param UserPolicyInterface $authUser
     * @param Apps $apps
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Apps $apps)
    {
        if ($authUser->canDo('app.apps.view') && $authUser->isAdmin()) {
            return true;
        }

        return $apps->user_id == user_id() && $apps->user_type == user_type();
    }

    /**
     * Determine if the given user can create a apps.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('app.apps.create');
    }

    /**
     * Determine if the given user can update the given apps.
     *
     * @param UserPolicyInterface $authUser
     * @param Apps $apps
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Apps $apps)
    {
        if ($authUser->canDo('app.apps.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $apps->user_id == user_id() && $apps->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given apps.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Apps $apps)
    {
        return $apps->user_id == user_id() && $apps->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given apps.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Apps $apps)
    {
        if ($authUser->canDo('app.apps.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given apps.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Apps $apps)
    {
        if ($authUser->canDo('app.apps.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
