<?php

namespace Litecms\App\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\App\Models\Permission;

class PermissionPolicy
{

    /**
     * Determine if the given user can view the permission.
     *
     * @param UserPolicyInterface $authUser
     * @param Permission $permission
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Permission $permission)
    {
        if ($authUser->canDo('app.permission.view') && $authUser->isAdmin()) {
            return true;
        }

        return $permission->user_id == user_id() && $permission->user_type == user_type();
    }

    /**
     * Determine if the given user can create a permission.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('app.permission.create');
    }

    /**
     * Determine if the given user can update the given permission.
     *
     * @param UserPolicyInterface $authUser
     * @param Permission $permission
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Permission $permission)
    {
        if ($authUser->canDo('app.permission.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $permission->user_id == user_id() && $permission->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given permission.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Permission $permission)
    {
        return $permission->user_id == user_id() && $permission->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given permission.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Permission $permission)
    {
        if ($authUser->canDo('app.permission.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given permission.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Permission $permission)
    {
        if ($authUser->canDo('app.permission.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
